import { Socket, Server } from 'socket.io'

import { gameLogger } from '#application/logger'
import { TSocket } from '#application/types'
import { Character } from '#entities/character'
import CharacterRepository from '#repositories/characterRepository'

export default class CharacterListEvent {
  constructor(
    private readonly io: Server,
    private readonly socket: TSocket
  ) {}

  public listen(): void {
    this.socket.on('character:list', this.handleCharacterList.bind(this))
  }

  private async handleCharacterList(data: any): Promise<void> {
    try {
      const characters: Character[] = await CharacterRepository.getByUserId(this.socket.userId!)
      this.socket.emit('character:list', characters)
    } catch (error: any) {
      gameLogger.error('character:list error', error.message)
    }
  }
}
